ClipperShape enum

Inheritance
Available extensions

Values

trigger → const ClipperShape

三角

star → const ClipperShape

五角星

circle → const ClipperShape

圆型

beveled → const ClipperShape

切角

continuous → const ClipperShape

连续矩形

rounded → const ClipperShape

圆角矩形

stadium → const ClipperShape

体育场,胶囊型

custom → const ClipperShape

自定义,需设置customShape

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ClipperShape>
A constant List of the values in this enum, in order of their declaration.