ClipperView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ClipperView
Constructors
- ClipperView({Key? key, required double width, required double height, required Color color, required ClipperShape shape, double elevation = 0.0, Color shadowColor = Colors.black, double starValleyRounding = 0.0, double starInnerRadiusRatio = 0.4, double starPointRounding = 0, double starPoints = 5, double starRotation = 0, double radius = 20, double eccentricity = 0.0, Clip clipBehavior = Clip.none, Widget? child, ShapeBorder? customShape, BorderSide side = BorderSide.none})
-
const
Properties
- child → Widget?
-
final
- clipBehavior → Clip
-
final
- color → Color
-
final
- customShape → ShapeBorder?
-
自定义形状,ClipperShape.custom需设置此参数
final
- eccentricity → double
-
ClipperShape.circle中圆到椭圆的离心率0.0-1.0
final
- elevation → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- radius → double
-
有圆角的圆角
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowColor → Color
-
final
- shape → ClipperShape
-
形状类型:ClipperShape.trigger, ClipperShape.star, ClipperShape.circle, ClipperShape.beveled, ClipperShape.continuous, ClipperShape.rounded, ClipperShape.stadium, ClipperShape.custom
final
- side → BorderSide
-
final
- starInnerRadiusRatio → double
-
五角星内角半径
final
- starPointRounding → double
-
尖角的圆润程度
final
- starPoints → double
-
五角星顶点数
final
- starRotation → double
-
五角星旋转角度
final
- starValleyRounding → double
-
五角星参数
内角的圆润程度
final
- width → double
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited