GroupPurchaseAvatar class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- GroupPurchaseAvatar
Constructors
-
GroupPurchaseAvatar({Key? key, required List<
String> avatars, AvatarImageBuilder? imageBuilder, double size = 40, double overlapRatio = 0.45, int maxVisibleCount = 4, GroupAvatarMode mode = GroupAvatarMode.dense, Duration duration = const Duration(milliseconds: 500), double? width, bool autoPlay = true, Duration interval = const Duration(seconds: 1), bool loop = true, int fixedCount = 3, TextDirection? textDirection, bool showExtraCount = true, bool scaleSpacingToFitWidth = true, Color borderColor = Colors.white, double borderWidth = 3, BoxBorder? border, bool useBoxShadow = true, Color extraBackgroundColor = const Color(0xFF1E6B58), TextStyle? extraTextStyle, Map<String, String> ? imageHeaders = const {'User-Agent' : 'Mozilla/5.0'}, ImageErrorWidgetBuilder? errorBuilder, String? placeholder, bool useDefaultPlaceholder = true, WidgetBuilder? placeholderBuilder}) -
const
Properties
- autoPlay → bool
-
final
-
avatars
→ List<
String> -
final
- border → BoxBorder?
-
final
- borderColor → Color
-
final
- borderWidth → double
-
final
- duration → Duration
-
final
- errorBuilder → ImageErrorWidgetBuilder?
-
final
- extraBackgroundColor → Color
-
final
- extraTextStyle → TextStyle?
-
final
- fixedCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageBuilder → AvatarImageBuilder?
-
final
-
imageHeaders
→ Map<
String, String> ? -
final
- interval → Duration
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loop → bool
-
final
- maxVisibleCount → int
-
final
- mode → GroupAvatarMode
-
final
- overlapRatio → double
-
final
- placeholder → String?
-
final
- placeholderBuilder → WidgetBuilder?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleSpacingToFitWidth → bool
-
final
- showExtraCount → bool
-
final
- size → double
-
final
- textDirection → TextDirection?
-
final
- useBoxShadow → bool
-
final
- useDefaultPlaceholder → bool
-
final
- width → double?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< GroupPurchaseAvatar> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited